@@ -8,17 +8,22 @@
 # #############################################################################
 import os
 import io
-import httpx
+import shutil
 from dataclasses import dataclass
 import datetime
-from . import compat
-FIX_SCENAR = compat.fix_scenar
-
-REQMAN_CONF='reqman.yml'
+import ast
+from types import CodeType
+import logging
 
+import httpx
 import ruamel.yaml
 from ruamel.yaml.comments import CommentedMap as YDict,CommentedSeq as YList
 
+from . import compat
+
+logger = logging.getLogger(__name__)
+
+REQMAN_CONF='reqman.yml'
 
 
 class BytesUtf8(bytes):
@@ -104,6 +109,17 @@ class Conf(dict):
 class RqException(Exception): 
     pass
 
+class ExeError(Exception):
+    def __init__(self,filename:str,line:int, message:str):
+        line = line if line else 0
+
+        self.filename=filename
+        self.line=line+1 if line>0 else 0
+        self.message=message
+    def __str__(self):
+        return f"[{self.filename}:{self.line}] {self.message}"
+
+
 def assert_syntax( condition:bool, msg:str):
     if not condition: raise RqException( msg )
 
@@ -198,7 +214,7 @@ class YScenario:
             self.filename = "buffer"
         self._conf,self._steps = load_scenar(yml)
         if compatibility>0:
-            self._conf,self._steps=FIX_SCENAR(self._conf,self._steps)
+            self._conf,self._steps=compat.fix_scenar(self._conf,self._steps)
             if compatibility>1:
                 self.save()
         self.conf = Conf( self._conf )
@@ -213,13 +229,12 @@ class YScenario:
         yaml.width = 200
         yaml.indent(mapping=2, sequence=2, offset=0)
         yaml.encoding = self.encoding
-        # shutil.copy2(self.filename,self.filename)
+        
 
         if self.filename != "buffer":
-            new_file=self.filename+".new.yml"
-            with open(new_file,"wb+") as fid:
+            shutil.copy2(self.filename,self.filename+".reqman3.yml")
+            with open(self.filename,"wb+") as fid:
                 yaml.dump(base, fid)
-            print("CREATE NEW REQMAN4 FILE:",new_file)
         else:
             f = io.BytesIO()
             yaml.dump(base, f)
@@ -229,5 +244,31 @@ class YScenario:
     def __str__(self):
         return f"YScenario '{self.filename}' ({self.encoding})\n* DICT:{self._conf}\n* LIST:{self._steps}"
 
+
+def check_python_code(s: str) -> str:
+    """ check if str is python code, return '' if ok else return the error """
+    try:
+        ast.parse(s)
+        return ""
+    except SyntaxError as e:
+        return str(e)
+
+def is_python(k,v) -> CodeType|None:
+    if isinstance(v,str) and "return" in v:
+        err=check_python_code(v)
+        if not err:
+
+            def declare(k:str,code:str) -> str:
+                return f"def {k}(x=None):\n" + ("\n".join(["  " + i for i in code.splitlines()]))
+
+            try:
+                logger.info("*** DECLARE METHOD PYTHON: %s",k)
+                return compile(declare(k,v), f"method '{k}'", "exec")
+            except Exception as e:
+                raise RqException(f"Python Compilation Error : {e}")
+        else:
+            logger.warning("Method '%s'() feels like python, but doesn't compile (%s)", k, err)
+
+
 if __name__=="__main__":
     ...
\ No newline at end of file
