@@ -198,6 +198,8 @@ class StepSet(Step):
         self.dico = dico
 
     async def process(self,e:env.Env) -> AsyncGenerator:
+        e.resolv()  # try to resolv max variables in env, before running http test
+        
         e.update( e.substitute_in_object(self.dico,True) )
         yield None
 
@@ -237,9 +239,9 @@ class Scenario(list):
     def steps(self) -> list:
         return self._ys._steps
 
-    def _feed(self, env:env.Env, liste:list[dict]) -> list[Step]:
+    def _feed(self, env:env.Env, liste:list[common.YDict]) -> list[Step]:
         try:
-            step=None
+            step=common.YDict()
             assert_syntax(isinstance(liste, list),"RUN must be a list")
 
             ll = []
@@ -266,9 +268,10 @@ class Scenario(list):
                             raise common.RqException(f"Bad Dict {step}")
             return ll
         except common.RqException as ex:
-            # this is an ERROR at compilation time
-            line_info = f":{step.lc.line+1}" if hasattr(step, 'lc') and step.lc else ""
-            raise common.RqException(f"[{self.file_path}{line_info}] [Bad {step}] [{ex}]")
+            # line_info = f":{step.lc.line+1}" if hasattr(step, 'lc') and step.lc else ""
+            # raise common.RqException(f"[{self.file_path}{line_info}] [Bad {step}] [{ex}]")
+            line = step.lc.line if hasattr(step, 'lc') and step.lc else 0
+            raise common.ExeError(self.file_path, line, str(ex))
     
     def __repr__(self):
         return super().__repr__()
@@ -276,7 +279,7 @@ class Scenario(list):
     async def execute(self,enw:env.Env,with_begin:bool=False,with_end:bool=False) -> AsyncGenerator:
         self.clear()
         self.extend( self._feed( enw, self.steps ) )
-        step=None
+        step=common.YDict()
         try:
 
             if with_begin and enw.get("BEGIN"):
@@ -296,24 +299,10 @@ class Scenario(list):
 
         except Exception as ex:
             # this is an ERROR at execution time
-            line_info = f":{step.line+1}" if hasattr(step, 'line') and step.line else ""
-            raise common.RqException(f"[{self.file_path}{line_info}] [Error {step}] [{ex}]")
+            # line_info = f":{step.line+1}" if hasattr(step, 'line') and step.line else ""
+            # raise common.RqException(f"[{self.file_path}{line_info}] [Error {step}] [{ex}]")
+            raise common.ExeError(self.file_path, step.line if hasattr(step, 'line') else 0, str(ex))
 
 
 
-if __name__ == "__main__":
-    ...
-    # logging.basicConfig(level=logging.DEBUG)
 
-    # async def run_a_test(f:str):
-    #     t=Scenario(f)
-    #     async for i in t.execute():
-    #         if i:
-    #             print(f"{i.request.method} {i.request.url} -> {i.response.status_code}")
-    #             for tr in i.tests:
-    #                 print(" -",tr.ok and "OK" or "KO",":", tr.text)
-    #             print()
-
-
-    # # asyncio.run( run_a_test("examples/ok/simple.yml") )
-    # asyncio.run( run_a_test("examples/ok/test1.yml") )
